@@ -1,5 +1,7 @@
 
+from __future__ import unicode_literals
 from django.db import models
+from django.utils.encoding import python_2_unicode_compatible
 from django.utils.translation import ugettext_lazy as _
 
 from email_extras.settings import USE_GNUPG, GNUPG_HOME
@@ -9,6 +11,7 @@ from email_extras.utils import addresses_for_key
 if USE_GNUPG:
     from gnupg import GPG
 
+    @python_2_unicode_compatible
     class Key(models.Model):
         """
         Accepts a key and imports it via admin's save_model which
@@ -25,7 +28,7 @@ if USE_GNUPG:
             "an '.asc' extension will be added to email attachments sent "
             "to the address for this key."))
 
-        def __unicode__(self):
+        def __str__(self):
             return self.addresses
 
         def save(self, *args, **kwargs):
@@ -41,6 +44,7 @@ if USE_GNUPG:
                 address.use_asc = self.use_asc
                 address.save()
 
+    @python_2_unicode_compatible
     class Address(models.Model):
         """
         Stores the address for a successfully imported key and allows
@@ -54,7 +58,7 @@ if USE_GNUPG:
         address = models.CharField(max_length=200)
         use_asc = models.BooleanField(default=False, editable=False)
 
-        def __unicode__(self):
+        def __str__(self):
             return self.address
 
         def delete(self):
